@@ -509,9 +509,9 @@ void plot_ac(struct subwin *sw, struct ac *ac){
     if (undercursor){
         fcolor = z_makecol(21, 193, 106);
         bcolor = z_makecol(15, 150, 70);
-	}else if (strcmp(ac->id, gacs->sh.tracked) == 0){
-		fcolor = z_makecol(255, 0, 0);
-		bcolor = z_makecol(192, 0, 0);
+	}else if (ac->id && *ac->id && strcmp(ac->id, gacs->sh.tracked) == 0){
+		fcolor = z_makecol(255, 0, 255);
+		bcolor = z_makecol(192, 0, 192);
 	}else if (ctp->path_valid == 1 && res->under){
         fcolor = z_makecol(128, 128, 128);
         bcolor = z_makecol(64, 64, 64);
@@ -722,19 +722,21 @@ void acs_goturl(struct zhttp *http){
         acs->http_timer = 0;
     }
 
-    data = g_new(char, http->response->len + 1);
-    zbinbuf_getstr(http->response, http->dataofs, data, http->response->len + 1);
+	if (http_is_content_type(http, "text/plain;charset=UTF-8")){
+		data = g_new(char, http->response->len + 1);
+		zbinbuf_getstr(http->response, http->dataofs, data, http->response->len + 1);
 
-    if (acs->http->errorstr == NULL){
-        z_split2(data, ';', &status, &url, 0);
-        if (status != NULL && status[0] == 'A'){
-            remains = 1;
-            acs->url = g_strdup(url);
-            g_free(status);
-            g_free(url);
-        }
-    }
-    g_free(data);
+		if (acs->http->errorstr == NULL){
+			z_split2(data, ';', &status, &url, 0);
+			if (status != NULL && status[0] == 'A'){
+				remains = 1;
+				acs->url = g_strdup(url);
+				g_free(status);
+				g_free(url);
+			}
+		}
+		g_free(data);
+	}
     zhttp_free(http);
     acs->http = NULL;
 
@@ -754,19 +756,21 @@ void acs_downloaded_callback(struct zhttp *http){
         acs->http_timer = 0;
     }
 
-    data = g_new(char, http->response->len + 1);
-    zbinbuf_getstr(http->response, http->dataofs, data, http->response->len + 1);
-    zhttp_free(http);
-    acs->http = NULL;
+	if (http_is_content_type(http, "application/json") || http_is_content_type(http, "text/plain;charset=UTF-8")){
+		data = g_new(char, http->response->len + 1);
+		zbinbuf_getstr(http->response, http->dataofs, data, http->response->len + 1);
+		zhttp_free(http);
+		acs->http = NULL;
+
+		MUTEX_LOCK(acs->sh);
+		g_free(acs->sh.data);
+		acs->sh.data = data;
+		MUTEX_UNLOCK(acs->sh);
+	}
 
     gettimeofday(&tv, NULL);
     remains = 60000 - ((tv.tv_sec % 60) * 1000 + tv.tv_usec/1000);
     acs->http_timer = zselect_timer_new(zsel, remains, acs_http_timer, acs);
-
-    MUTEX_LOCK(acs->sh);
-    g_free(acs->sh.data);
-    acs->sh.data = data;
-    MUTEX_UNLOCK(acs->sh);
 }
 
 gpointer acs_thread(gpointer arg){
@@ -1095,6 +1099,7 @@ int acs_get_wingspan(struct acs *acs, char *icao){
     return 0;
 }
 
+#ifdef Z_HAVE_SDL
 struct ac *ac_under(struct acs *acs, struct subwin *sw){
 	struct ac *ac, *ret = NULL;
 	int i;
@@ -1115,6 +1120,7 @@ struct ac *ac_under(struct acs *acs, struct subwin *sw){
 	MUTEX_UNLOCK(acs->sh);
 	return ret;
 }
+#endif
 
 void ac_track(struct acs *acs, char *id, int rotnr){
 	if (!acs) return;
