@@ -233,6 +233,13 @@ struct dsp *init_dsp(enum dsp_type type, enum dsp_cfg_group dcg){
             log_addf("No support for librtlsdr");
 #endif
             break;
+		case DSPT_HAMLIB:
+#ifdef HAVE_HAMLIB
+			// keep dummy
+#else			
+			log_addf("No support for hamlib");
+#endif
+			break;
         default:
             zinternal("bad dsp->type");
             break;
