@@ -1152,6 +1152,20 @@ destroy:;
                     continue;
                 }
                 if (strncmp(gs->str,"Q ",2)==0){
+					gchar **items;
+					items = g_strsplit(gs->str + 2, ";", 0);
+
+					char *c = g_strdup_printf("%s%s", items[14], items[0]);
+					process_input(b, c, 0);
+					g_free(c);
+
+					GString *t = g_string_new(items[1]);
+					if (t->len > 2) g_string_insert(t, 2, ":");
+					process_input(b, t->str, 0);
+					g_string_free(t, TRUE);
+
+					g_strfreev(items);
+					
                     process_input(b, "", 0);
                     continue;
                 }
