@@ -360,6 +360,7 @@ show_history:
                     g_free(clipboard);*/
                     goto dsp_f;
                 }
+#ifdef Z_HAVE_SDL                                          
 				case ACT_AC_INFO:
 					if (il->readonly) break;
 					il->cdata[il->cpos] = 0;
@@ -383,6 +384,7 @@ show_history:
 					}
 					goto dsp_f;
 					break;
+#endif                    
                 default:
                     if (cfg->slashkey && *cfg->slashkey){
                         if (ev->x == '/') ev->x = *cfg->slashkey;
@@ -391,6 +393,14 @@ show_history:
                     if (ev->x >= ' ' && ev->x < 0x100 && !ev->y) {
                         char c;
                         if (il->readonly) break;
+						dbg("gses->last_cq = %p\n", gses->last_cq);
+						if (il->band && gses->last_cq){
+							if ((gses->last_cq->mode == MOD_CW_CW && gses->last_cq->cw_breakable) ||
+								(gses->last_cq->mode != MOD_CW_CW && gses->last_cq->ssb_breakable)){
+
+								cq_abort(0);
+							}
+						}
                         if (strlen(il->cdata) < il->dlen - 1) {
                             memmove(il->cdata + il->cpos + 1, il->cdata + il->cpos, strlen(il->cdata) - il->cpos + 1);
                             c = ev->x;
