@@ -30,7 +30,8 @@
 
 char *kst_servers[] = {"www.on4kst.info", 
                        "on4kst.dyndns.org", 
-                       "188.165.198.144", // www.on4kst.info 11.3.2015
+					   "141.94.171.16", // www.on4kst.info 22.11.2021
+					   //"188.165.198.144", // www.on4kst.info 11.3.2015
                        NULL};
 int kst_i = 0;
 
@@ -621,8 +622,10 @@ void sw_kst_enter(void *enterdata, gchar *str, int cq){
             sw_kst_disconnect(sw);
             return;
         }
-        send(sw->sock, str, strlen(str), 0);
-        send(sw->sock, "\r\n", 2, 0);
+		zbinbuf_append(sw->wrbuf, str);
+		zbinbuf_append(sw->wrbuf, "\r\n");
+		zselect_set_write(zsel, sw->sock, sw_kst_write_handler, sw);
+
         if (strcasecmp(str, "/sh us") == 0) kst_shus(sw, 2);
     }
 }
@@ -666,6 +669,7 @@ void sw_kst_addrinfo(struct zasyncdns *adns, int n, int *family, int *socktype,
         }
         if (z_sock_nonblock(sw->sock, 1)) {
             closesocket(sw->sock);
+			sw->sock = -1;
             continue;
         }
 
@@ -680,6 +684,7 @@ void sw_kst_addrinfo(struct zasyncdns *adns, int n, int *family, int *socktype,
 #endif
             default:   
                 closesocket(sw->sock);
+				sw->sock = -1;
                 continue;       // unsupported protocol family
         }
         ret = connect(sw->sock, (struct sockaddr *)(addr + i), addrlen[i]);
@@ -692,8 +697,8 @@ void sw_kst_addrinfo(struct zasyncdns *adns, int n, int *family, int *socktype,
             }else{
                 sw_printf(sw, VTEXT(T_CANT_CONNECT_TO), z_sock_ntoa(gs2, family[i], addr + i), z_sock_strerror());
                 closesocket(sw->sock);
-                dbg("sw_kst_addrinfo -1\n");
-                sw->sock = -1;
+				sw->sock = -1;
+				dbg("sw_kst_addrinfo -1\n");
             }
             g_string_free(gs2, TRUE);
         }
@@ -764,13 +769,15 @@ void sw_kst_read_handler(void *xxx){
     if (!regcmpi(last, "^login:")){
         if (cfg->kst_user && *cfg->kst_user){
             sw_printf(sw,           "%s\r\n", cfg->kst_user);
-            z_sock_printf(sw->sock, "%s\r\n", cfg->kst_user);
+			zbinbuf_sprintfa(sw->wrbuf, "%s\r\n", cfg->kst_user);
+			zselect_set_write(zsel, sw->sock, sw_kst_write_handler, sw);
         }
     }
     if (!regcmpi(last, "^password:")){
         if (cfg->kst_pass && *cfg->kst_pass){
             sw_printf(sw, "********\r\n");
-            z_sock_printf(sw->sock, "%s\r\n", cfg->kst_pass);
+			zbinbuf_sprintfa(sw->wrbuf, "%s\r\n", cfg->kst_pass);
+			zselect_set_write(zsel, sw->sock, sw_kst_write_handler, sw);
         }
     } 
     if (!regcmpi(last, "^Your\\ choice.*:")){
@@ -794,18 +801,21 @@ void sw_kst_read_handler(void *xxx){
         }
         if (channel > 0){
             sw_printf(sw,           "%d\r\n", channel);
-            z_sock_printf(sw->sock, "%d\r\n", channel);
+			zbinbuf_sprintfa(sw->wrbuf, "%d\r\n", channel);
+			zselect_set_write(zsel, sw->sock, sw_kst_write_handler, sw);
         }
     }
     if (!regcmpi(last, ">$")){
         if (cfg->kst_name && *cfg->kst_name){
             sw_printf(sw,           "/set name %s\r\n", cfg->kst_name);
-            z_sock_printf(sw->sock, "/set name %s\r\n", cfg->kst_name);
+			zbinbuf_sprintfa(sw->wrbuf, "/set name %s\r\n", cfg->kst_name);
+			zselect_set_write(zsel, sw->sock, sw_kst_write_handler, sw);
         }
         if (ctest != NULL){
             sw_printf(sw,           "/set qra %s\r\n", ctest->pwwlo);
-            z_sock_printf(sw->sock, "/set qra %s\r\n", ctest->pwwlo);
-        }
+			zbinbuf_sprintfa(sw->wrbuf, "/set qra %s\r\n", ctest->pwwlo);
+			zselect_set_write(zsel, sw->sock, sw_kst_write_handler, sw);
+		}
         sw->chat = 0;
         if (sw->timer_id > 0) zselect_timer_kill(zsel, sw->timer_id);
         sw->timer_id = zselect_timer_new(zsel, 1 * 1000, kst_timer_function, sw);
@@ -1337,7 +1347,6 @@ int kst_read_line(struct subwin *sw, char *line){
 }
 
 void kst_timer_function(void *data){
-    char *c;
     struct subwin *sw = (struct subwin *)data;
 
     //log_addf("-----");
@@ -1356,8 +1365,9 @@ void kst_timer_function(void *data){
     }
 
     sw_add_block(sw, VTEXT(T_SENDING_SH_US));
-    c = "/sh us\r\n";
-    send(sw->sock, c, strlen(c), 0);
+	zbinbuf_append(sw->wrbuf, "/sh us\r\n");
+	zselect_set_write(zsel, sw->sock, sw_kst_write_handler, sw);
+
     kst_shus(sw, 1);
     
     //log_addf("kst_timer_function exit shus=%d", sw->shus);
@@ -1633,3 +1643,20 @@ GPtrArray* sw_kst_calls_under(struct subwin *sw, int n, int y){
 	}
 	return ret;
 }
+
+void sw_kst_write_handler(void *arg){
+	struct subwin *sw = (struct subwin *)arg;
+
+	int len = sw->wrbuf->len;
+	if (len > 1400) len = 1400;
+	int ret = send(sw->sock, sw->wrbuf->buf, len, 0);
+	if (ret <= 0){
+		sw_kst_disconnect(sw);
+		return;
+	}
+
+	zbinbuf_erase(sw->wrbuf, 0, ret);
+	if (sw->wrbuf->len == 0) zselect_set_write(zsel, sw->sock, NULL, sw);
+	
+
+}
