@@ -56,7 +56,7 @@
 #include "terminal.h"
 #include "trig.h"
 //#include "update.h"
-#include "vhfcontestnet.h"
+//#include "vhfcontestnet.h"
 #include "slovhfnet.h"
 #include "wizz.h"
 
@@ -1139,7 +1139,7 @@ int main(int argc, char *argv[])
     
     exit(1);
 #endif  
-	//zfence_init(16, '\0', 0xee);
+	//zfence_init(256, '\0', 0xee);
 #ifdef Z_MINGW
 //    MessageBox(NULL, "Hello World, I'm Tucnak compiled under mingw", "Info", MB_OK);
 
