@@ -47,7 +47,7 @@
 #include "terminal.h"
 #include "tregex.h"
 #include "update.h"
-#include "vhfcontestnet.h"
+//#include "vhfcontestnet.h"
 #include "slovhfnet.h"
 #include "sota.h"
 #include "sota_spot.h"
