@@ -910,7 +910,8 @@ void wizz_func (void *arg){
     g_snprintf(tdate, MAX_STR_LEN, "%d%02d%02d", 1900+utc.tm_year, 1+utc.tm_mon, utc.tm_mday);
     qsoused=wi->qsoused;
     g_snprintf(qsomult_str,10, "%d", wi->qsomult);
-    qsoglob=wi->qsoglob;
+	qsoglob = wi->qsoglob;
+	expmode = wi->expmode;
     wwlused=wi->wwlused;
     safe_strncpy0(wwltype_str, get_text_translation(wwltype_msg[wwlused]), MAX_STR_LEN);
     g_snprintf(wwlbonu_str,10, "%d", wi->wwlbonu);
@@ -937,7 +938,6 @@ void wizz_func (void *arg){
     defrstr=wi->defrstr;
     tttype=wi->tttype;
     safe_strncpy0(tttype_str, get_text_translation(tttype_msg[tttype]), MAX_STR_LEN);
-    expmode=0;
 	phase = 1;
 
     
@@ -1420,7 +1420,7 @@ void contest_options1(char *title, int from_ctest, struct wizz_item *wi)
     d->items[++i].type = D_FIELD;      /* 10 */
     d->items[i].data = wwlbonu_str;
     d->items[i].dlen = 8;
-    d->items[i].maxl = 3;
+    d->items[i].maxl = 4;
     d->items[i].fn   = check_number;
     d->items[i].gid  = 0;
     d->items[i].gnum = 999999;
@@ -1454,7 +1454,7 @@ void contest_options1(char *title, int from_ctest, struct wizz_item *wi)
     d->items[++i].type = D_FIELD;
     d->items[i].data = excbonu_str;
     d->items[i].dlen = 8;
-    d->items[i].maxl = 3;
+    d->items[i].maxl = 4;
     d->items[i].fn   = check_number;
     d->items[i].gid  = 0;
     d->items[i].gnum = 999999;
@@ -1506,7 +1506,7 @@ void contest_options1(char *title, int from_ctest, struct wizz_item *wi)
     d->items[++i].type = D_FIELD; 
     d->items[i].data = dxcbonu_str;
     d->items[i].dlen = 8;
-    d->items[i].maxl = 3;
+    d->items[i].maxl = 4;
     d->items[i].fn   = check_number;
     d->items[i].gid  = 0;
     d->items[i].gnum = 999999;
