@@ -36,7 +36,7 @@ struct menu_item no_cq_defined_menu[] = {
 /************************** CW *******************************/
  
 char cw_str[MAX_STR_LEN], cw_speed_str[EQSO_LEN];
-int cw_repeat;
+int cw_repeat, cw_breakable;
 char cw_ts_str[EQSO_LEN];
 int cw_allowifundef;    
 
@@ -48,7 +48,8 @@ void refresh_cq_cw(void *xxx){
     
     STORE_STR(cq, cw_str);
     cq->cw_speed = atoi(cw_speed_str);
-    cq->cw_repeat = cw_repeat;
+	cq->cw_repeat = cw_repeat;
+	cq->cw_breakable = cw_breakable;
     cq->cw_ts  = atoi(cw_ts_str);
     cq->cw_allowifundef = cw_allowifundef;
 }
@@ -57,6 +58,7 @@ char *cq_cw_msg[] = {
    CTEXT(T_TEXT), 
    CTEXT(T_SPEED), 
    CTEXT(T_REPEAT),
+   TRANSLATE("Breakable"),
    CTEXT(T_DELAY), 
    CTEXT(T_ALLOW_UNDEF),
    "", /* OK */
@@ -81,9 +83,11 @@ void cq_cw_fn(struct dialog_data *dlg)
     min_group_width(term, cq_cw_msg + 3, dlg->items + 2, 1, &min);
     max_group_width(term, cq_cw_msg + 4, dlg->items + 2, 1, &max);
     min_group_width(term, cq_cw_msg + 4, dlg->items + 2, 1, &min);
-    
-    max_buttons_width(term, dlg->items + 5, 2, &max);
-    min_buttons_width(term, dlg->items + 5, 2, &min);
+	max_group_width(term, cq_cw_msg + 5, dlg->items + 2, 1, &max);
+	min_group_width(term, cq_cw_msg + 5, dlg->items + 2, 1, &min);
+
+    max_buttons_width(term, dlg->items + 6, 2, &max);
+    min_buttons_width(term, dlg->items + 6, 2, &min);
     
     w = dlg->win->term->x * 9 / 10 - 2 * DIALOG_LB;
     if (w > max) w = max;
@@ -97,9 +101,10 @@ void cq_cw_fn(struct dialog_data *dlg)
     dlg_format_group(NULL, term, cq_cw_msg + 1, dlg->items + 1, 1, 0, &y, w, &rw);
     dlg_format_group(NULL, term, cq_cw_msg + 2, dlg->items + 2, 1, 0, &y, w, &rw);
     dlg_format_group(NULL, term, cq_cw_msg + 3, dlg->items + 3, 1, 0, &y, w, &rw);
-    dlg_format_group(NULL, term, cq_cw_msg + 4, dlg->items + 4, 1, 0, &y, w, &rw);
+	dlg_format_group(NULL, term, cq_cw_msg + 4, dlg->items + 4, 1, 0, &y, w, &rw);
+	dlg_format_group(NULL, term, cq_cw_msg + 5, dlg->items + 5, 1, 0, &y, w, &rw);
     y++;
-    dlg_format_buttons(NULL, term, dlg->items + 5, 2, 0, &y, w, &rw, AL_LEFT);
+    dlg_format_buttons(NULL, term, dlg->items + 6, 2, 0, &y, w, &rw, AL_LEFT);
     
     
     w = rw;
@@ -115,9 +120,10 @@ void cq_cw_fn(struct dialog_data *dlg)
     dlg_format_group(term, term, cq_cw_msg + 1, dlg->items + 1, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
     dlg_format_group(term, term, cq_cw_msg + 2, dlg->items + 2, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
     dlg_format_group(term, term, cq_cw_msg + 3, dlg->items + 3, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
-    dlg_format_group(term, term, cq_cw_msg + 4, dlg->items + 4, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
+	dlg_format_group(term, term, cq_cw_msg + 4, dlg->items + 4, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
+	dlg_format_group(term, term, cq_cw_msg + 5, dlg->items + 5, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
     y++;
-    dlg_format_buttons(term, term, dlg->items + 5, 2, dlg->x + DIALOG_LB, &y, w, NULL, AL_LEFT);
+    dlg_format_buttons(term, term, dlg->items + 6, 2, dlg->x + DIALOG_LB, &y, w, NULL, AL_LEFT);
     
 }
 
@@ -134,7 +140,8 @@ void cq_cw(void *arg){
     
     safe_strncpy0(cw_str, cq->cw_str, MAX_STR_LEN);
     g_snprintf(cw_speed_str, EQSO_LEN, "%d", cq->cw_speed);
-    cw_repeat = cq->cw_repeat;
+	cw_repeat = cq->cw_repeat;
+	cw_breakable = cq->cw_breakable;
     g_snprintf(cw_ts_str, EQSO_LEN, "%d", cq->cw_ts);
     cw_allowifundef = cq->cw_allowifundef;
 
@@ -164,7 +171,13 @@ void cq_cw(void *arg){
     d->items[i].dlen = sizeof(int);
     d->items[i].data = (void *)&cw_repeat;
     
-    d->items[++i].type = D_FIELD;
+	d->items[++i].type = D_CHECKBOX;
+	d->items[i].gid = 0;
+	d->items[i].gnum = 1;
+	d->items[i].dlen = sizeof(int);
+	d->items[i].data = (void *)&cw_breakable;
+
+	d->items[++i].type = D_FIELD;
     d->items[i].dlen = EQSO_LEN;
     d->items[i].data = cw_ts_str;
     d->items[i].fn   = check_number;
@@ -224,7 +237,7 @@ void menu_cq_cw(void *arg){
 /*********************** SSB ****************************/
 
 char ssb_file[MAX_STR_LEN];
-int ssb_repeat;
+int ssb_repeat, ssb_breakable;
 char ssb_ts_str[EQSO_LEN];
 
 void refresh_cq_ssb(void *xxx){
@@ -233,13 +246,15 @@ void refresh_cq_ssb(void *xxx){
     cq = (struct cq *)xxx;
     
     STORE_STR(cq, ssb_file);
-    cq->ssb_repeat = ssb_repeat;
+	cq->ssb_repeat = ssb_repeat;
+	cq->ssb_breakable = ssb_breakable;
     cq->ssb_ts  = atoi(ssb_ts_str);
 }
 
 char *cq_ssb_msg[] = {
    CTEXT(T_FILENAME), 
    CTEXT(T_REPEAT),
+   TRANSLATE("Breakable"),
    CTEXT(T_DELAY), 
    "", /* OK */
    "", /* Cancel */
@@ -259,9 +274,11 @@ void cq_ssb_fn(struct dialog_data *dlg)
     min_group_width(term, cq_ssb_msg + 1, dlg->items + 1, 1, &min);
     max_group_width(term, cq_ssb_msg + 2, dlg->items + 2, 1, &max);
     min_group_width(term, cq_ssb_msg + 2, dlg->items + 2, 1, &min);
-    
-    max_buttons_width(term, dlg->items + 3, 2, &max);
-    min_buttons_width(term, dlg->items + 3, 2, &min);
+	max_group_width(term, cq_ssb_msg + 3, dlg->items + 3, 1, &max);
+	min_group_width(term, cq_ssb_msg + 3, dlg->items + 3, 1, &min);
+
+    max_buttons_width(term, dlg->items + 4, 2, &max);
+    min_buttons_width(term, dlg->items + 4, 2, &min);
     
     w = dlg->win->term->x * 9 / 10 - 2 * DIALOG_LB;
     if (w > max) w = max;
@@ -273,9 +290,10 @@ void cq_ssb_fn(struct dialog_data *dlg)
     y ++;
     dlg_format_group(NULL, term, cq_ssb_msg + 0, dlg->items + 0, 1, 0, &y, w, &rw);
     dlg_format_group(NULL, term, cq_ssb_msg + 1, dlg->items + 1, 1, 0, &y, w, &rw);
-    dlg_format_group(NULL, term, cq_ssb_msg + 2, dlg->items + 2, 1, 0, &y, w, &rw);
+	dlg_format_group(NULL, term, cq_ssb_msg + 2, dlg->items + 2, 1, 0, &y, w, &rw);
+	dlg_format_group(NULL, term, cq_ssb_msg + 3, dlg->items + 3, 1, 0, &y, w, &rw);
     y++;
-    dlg_format_buttons(NULL, term, dlg->items + 3, 2, 0, &y, w, &rw, AL_LEFT);
+    dlg_format_buttons(NULL, term, dlg->items + 4, 2, 0, &y, w, &rw, AL_LEFT);
     
     
     w = rw;
@@ -289,9 +307,10 @@ void cq_ssb_fn(struct dialog_data *dlg)
     y++;
     dlg_format_group(term, term, cq_ssb_msg + 0, dlg->items + 0, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
     dlg_format_group(term, term, cq_ssb_msg + 1, dlg->items + 1, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
-    dlg_format_group(term, term, cq_ssb_msg + 2, dlg->items + 2, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
+	dlg_format_group(term, term, cq_ssb_msg + 2, dlg->items + 2, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
+	dlg_format_group(term, term, cq_ssb_msg + 3, dlg->items + 3, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
     y++;
-    dlg_format_buttons(term, term, dlg->items + 3, 2, dlg->x + DIALOG_LB, &y, w, NULL, AL_LEFT);
+    dlg_format_buttons(term, term, dlg->items + 4, 2, dlg->x + DIALOG_LB, &y, w, NULL, AL_LEFT);
     
 }
 
@@ -307,7 +326,8 @@ void cq_ssb(void *arg){
     cq = g_ptr_array_index(cfg->cqs, no);
     
     safe_strncpy0(ssb_file, cq->ssb_file, MAX_STR_LEN);
-    ssb_repeat = cq->ssb_repeat;
+	ssb_repeat = cq->ssb_repeat;
+	ssb_breakable = cq->ssb_breakable;
     g_snprintf(ssb_ts_str, EQSO_LEN, "%d", cq->ssb_ts);
 
     
@@ -329,7 +349,13 @@ void cq_ssb(void *arg){
     d->items[i].dlen = sizeof(int);
     d->items[i].data = (void *)&ssb_repeat;
     
-    d->items[++i].type = D_FIELD;
+	d->items[++i].type = D_CHECKBOX;
+	d->items[i].gid = 0;
+	d->items[i].gnum = 1;
+	d->items[i].dlen = sizeof(int);
+	d->items[i].data = (void *)&ssb_breakable;
+
+	d->items[++i].type = D_FIELD;
     d->items[i].dlen = EQSO_LEN;
     d->items[i].data = ssb_ts_str;
     d->items[i].fn   = check_number;
@@ -502,9 +528,19 @@ void menu_cwda(void *arg){
     d->items[i].gnum = CWD_WINKEYTCP;
     d->items[i].dlen = sizeof(int);
     d->items[i].data = (char *)&cwda_type;
-    d->items[i].msg = "winkey TCP";
+	d->items[i].msg = "winkey TCP";
 	d->items[i].wrap = 1;
 
+#ifdef HAVE_HAMLIB
+	d->items[++i].type = D_CHECKBOX;
+	d->items[i].gid = 1;
+	d->items[i].gnum = CWD_HAMLIB;
+	d->items[i].dlen = sizeof(int);
+	d->items[i].data = (char *)&cwda_type;
+	d->items[i].msg = CTEXT(T_ROT_HAMLIB);
+	d->items[i].wrap = 1;
+#endif
+
 	d->items[++i].type = D_FIELD;
     d->items[i].dlen = MAX_STR_LEN;
     d->items[i].data = cwda_device;
@@ -1072,6 +1108,15 @@ void do_ssbd(void){
     d->items[i].msg = CTEXT(T_SDR);
 #endif
 
+#ifdef HAVE_HAMLIB
+	d->items[++i].type = D_CHECKBOX;
+	d->items[i].gid = 1;
+	d->items[i].gnum = DSPT_HAMLIB;
+	d->items[i].dlen = sizeof(int);
+	d->items[i].data = (char *)&ssbd_type;
+	d->items[i].msg = CTEXT(T_ROT_HAMLIB);
+#endif
+
 	d->items[i].wrap = 1;
     
     d->items[++i].type = D_CHECKBOX;
