@@ -546,7 +546,7 @@ void rain_meteox_downloaded(struct zhttp *http){
 		sw_set_gdirty(SWT_MAP);
 		return;
 	}
-
+	
     newimg = zpng_create(http->response->buf + http->dataofs, http->response->len - http->dataofs);
     if (newimg == NULL){
         dbg("Can't read bitmap\n");
@@ -1257,22 +1257,24 @@ void rain_rainviewer_downloaded_json(struct zhttp *http){
 	if (http->state == ZHTTPST_ERROR && http->errorstr){
 		dbg("ERROR rain_rainviewer_downloaded_json: %s\n", http->errorstr);
 	}
-
 	dbg("rain_rainviewer_downloaded_json: got %d bytes\n", http->response->len - http->dataofs);
 
-	if (provider->rain->debug) zbinbuf_write_to_file(http->response, "_rainviewer.json", http->dataofs, http->response->len - http->dataofs);
+	if (http_is_content_type(http, "application/json")){
 
-	char *json = g_new(char, http->response->len + 1);
-	zbinbuf_getstr(http->response, http->dataofs, json, http->response->len + 1);
-	zhttp_free(http);
-	provider->http = NULL;
+		if (provider->rain->debug) zbinbuf_write_to_file(http->response, "_rainviewer.json", http->dataofs, http->response->len - http->dataofs);
 
-	rain_rainviewer_process_json(provider, json);
-	g_free(json);
+		char *json = g_new(char, http->response->len + 1);
+		zbinbuf_getstr(http->response, http->dataofs, json, http->response->len + 1);
+		zhttp_free(http);
+		provider->http = NULL;
+
+		rain_rainviewer_process_json(provider, json);
+		g_free(json);
+
+	}
 
 	g_assert(provider->timer_id == 0);
 	provider->timer_id = zselect_timer_new(zsel, 60 * 1000, rain_rainviewer_timer, provider);
-
 }
 
 void rain_rainviewer_process_json(struct rain_provider *provider, const char *json){
@@ -1341,33 +1343,33 @@ void rain_rainviewer_downloaded_image(struct zhttp *http){
 		return;
 	}
 
+	if (http_is_content_type(http, "image/png")){
+		dbg("rain_rainviewer_downloaded_image: got %d bytes\n", http->response->len - http->dataofs);
 
-	dbg("rain_rainviewer_downloaded_image: got %d bytes\n", http->response->len - http->dataofs);
-
-	if (provider->rain->debug) zbinbuf_write_to_file(http->response, "_rainviewer.png", http->dataofs, http->response->len - http->dataofs);
+		if (provider->rain->debug) zbinbuf_write_to_file(http->response, "_rainviewer.png", http->dataofs, http->response->len - http->dataofs);
 
 
-	newimg = zpng_create(http->response->buf + http->dataofs, http->response->len - http->dataofs);
-	if (newimg == NULL){
-		dbg("Can't read rainviewer bitmap\n");
-		provider->pal = provider->rain->bwcolors;
-		g_free(provider->rv_oldpath);
-		provider->rv_oldpath = NULL;
-	}
-	else{
-		dbg("rainviewer bitmap loaded, %dx%d\n", newimg->w, newimg->h);
-		if (provider->img != NULL) {
-			SDL_FreeSurface(provider->img);
+		newimg = zpng_create(http->response->buf + http->dataofs, http->response->len - http->dataofs);
+		if (newimg == NULL){
+			dbg("Can't read rainviewer bitmap\n");
+			provider->pal = provider->rain->bwcolors;
+			g_free(provider->rv_oldpath);
+			provider->rv_oldpath = NULL;
 		}
-		provider->img = newimg;
-		provider->pal = provider->rain->colors;
-		rain_rainviewer_load(provider);
-		rain_analyze_scps(provider->rain);
-
+		else{
+			dbg("rainviewer bitmap loaded, %dx%d\n", newimg->w, newimg->h);
+			if (provider->img != NULL) {
+				SDL_FreeSurface(provider->img);
+			}
+			provider->img = newimg;
+			provider->pal = provider->rain->colors;
+			rain_rainviewer_load(provider);
+			rain_analyze_scps(provider->rain);
+		}
+		zhttp_free(http);
+		provider->http = NULL;
+		sw_set_gdirty(SWT_MAP);
 	}
-	zhttp_free(http);
-	provider->http = NULL;
-	sw_set_gdirty(SWT_MAP);
 	g_assert(provider->timer_id == 0);
 	provider->timer_id = zselect_timer_new(zsel, 1 * 60 * 1000, rain_rainviewer_timer, provider);
 
