@@ -369,7 +369,7 @@ struct subwin *new_subwin(enum sw_type type, int where_){
 			map_update_qth(sw);
 #endif
 			sw->first_shus = 1;
-
+			sw->wrbuf = zbinbuf_init();
 
 			{
 				FILE *f;
@@ -497,6 +497,7 @@ void free_subwin(struct subwin *sw){
 	zg_ptr_array_free_all(sw->callsunder);
 	g_free(sw->pattern);
 	g_free(sw->player_filename);
+	zbinbuf_free(sw->wrbuf);
     g_free(sw);
 }
 
