@@ -274,7 +274,7 @@ void trigs_toggle_split_vfo(struct trigs *trigs){
 		gtrigs->split_vfo = RIG_VFO_MAIN;
 	}
 
-	TRTR(0, "trigs_toggle_split_vfo  split_vfo=%s", gtrigs->split_vfo == RIG_VFO_MAIN ? "MAIN" : "SUB");
+	TRTR(0, " trigs_toggle_split_vfo  split_vfo=%s", gtrigs->split_vfo == RIG_VFO_MAIN ? "MAIN" : "SUB");
 	
 	for (i = 0; i < trigs->trigs->len; i++){
 		struct trig *trig;
@@ -283,6 +283,50 @@ void trigs_toggle_split_vfo(struct trigs *trigs){
 	}
 }
 
+void trigs_send_voice_mem(struct trigs *trigs, int ch){
+
+#ifdef HAVE_RIG_SEND_VOICE_MEM
+	if (trigs == NULL) return;
+	TRTR(0, " trigs_send_voice_mem  %d", ch);
+
+	int i;
+	for (i = 0; i < trigs->trigs->len; i++){
+		struct trig *trig;
+		trig = (struct trig *)g_ptr_array_index(trigs->trigs, i);
+		trig_send_voice_mem(trig, ch);
+	}
+#endif    
+}
+
+void trigs_send_morse(struct trigs *trigs, const char *msg){
+
+#ifdef HAVE_RIG_SEND_MORSE
+    if (trigs == NULL) return;
+	TRTR(0, " trigs_send_morse  '%s'", msg);
+
+	int i;
+	for (i = 0; i < trigs->trigs->len; i++){
+		struct trig *trig;
+		trig = (struct trig *)g_ptr_array_index(trigs->trigs, i);
+		trig_send_morse(trig, msg);
+	}
+#endif    
+}
+
+void trigs_stop_morse(struct trigs *trigs){
+
+#ifdef HAVE_RIG_STOP_MORSE
+	int i;
+	if (trigs == NULL) return;
+	TRTR(0, " trigs_stop_morse");
+
+	for (i = 0; i < trigs->trigs->len; i++){
+		struct trig *trig;
+		trig = (struct trig *)g_ptr_array_index(trigs->trigs, i);
+		trig_stop_morse(trig);
+	}
+#endif    
+}
 
 
 // ---------------- trig functions
@@ -459,6 +503,48 @@ void trig_toggle_split_vfo(struct trig *trig){
 	trig_job_add(trig, job);
 }
 
+#ifdef HAVE_RIG_SEND_VOICE_MEM
+void trig_send_voice_mem(struct trig *trig, int ch){
+	struct trig_job *job;
+
+	if (!trig) return;
+
+	job = g_new0(struct trig_job, 1);
+	job->cmd = TRIG_SEND_VOICE_MEM;
+	job->ch = ch;
+	TRTR(0, "#%d: Send voice mem %d", trig->nr, ch);
+	trig_job_add(trig, job);
+}
+#endif
+                                                
+#ifdef HAVE_RIG_SEND_MORSE
+void trig_send_morse(struct trig *trig, const char *msg){
+	struct trig_job *job;
+
+	if (!trig) return;
+
+	job = g_new0(struct trig_job, 1);
+	job->cmd = TRIG_SEND_MORSE;
+	job->msg = g_strdup(msg);
+	TRTR(0, "#%d: Send morse '%s'", trig->nr, msg);
+	trig_job_add(trig, job);
+}
+#endif
+
+#ifdef HAVE_RIG_STOP_MORSE
+void trig_stop_morse(struct trig *trig){
+	struct trig_job *job;
+
+	if (!trig) return;
+
+	job = g_new0(struct trig_job, 1);
+	job->cmd = TRIG_STOP_MORSE;
+	TRTR(0, "#%d: Stop morse", trig->nr);
+	trig_job_add(trig, job);
+}
+#endif
+
+
 void trig_job_add(struct trig *trig, struct trig_job *job){
     MUTEX_LOCK(trig->jobs);
     add_to_list(trig->jobs, job);
@@ -495,6 +581,8 @@ gpointer trig_main(gpointer xxx){
     freq = oldfreq = (freq_t)0;
     rit = oldrit = (shortfreq_t)0;
     
+	const struct rig_caps *caps = rig_get_caps(trig->model);
+
 
     trig->rig = rig_init(trig->model);
     if (!trig->rig){
@@ -589,19 +677,21 @@ gpointer trig_main(gpointer xxx){
 				zselect_msg_send(zsel, "TRIG;%d;qrg;%"PRIfreq"", trig->nr, freq);
             }  
 
-            rigerr = rig_get_rit(trig->rig, vfo, &tmprit);
-            if (rigerr != RIG_OK && rigerr != -RIG_ENAVAIL){ 
-                gtrigs->rigerr = trig->rigerr = rigerr;
-				TRTR(1, "rig_get_rit(#%d, %s)", trig->nr, rig_strvfo(vfo));
-            } 
-            if (rigerr == RIG_OK){
-                rit = tmprit;
-                if (rit != oldrit){
-                    oldrit = rit;
-				    TRTR(1, "rig_get_rit(#%d, %s, %ld)", trig->nr, rig_strvfo(vfo), rit);
-				    zselect_msg_send(zsel, "TRIG;%d;rit;%ld", trig->nr, rit);
-                }
-            }  
+			if (caps->get_rit){
+				rigerr = rig_get_rit(trig->rig, vfo, &tmprit);
+				if (rigerr != RIG_OK && rigerr != -RIG_ENAVAIL){
+					gtrigs->rigerr = trig->rigerr = rigerr;
+					TRTR(1, "rig_get_rit(#%d, %s)", trig->nr, rig_strvfo(vfo));
+				}
+				if (rigerr == RIG_OK){
+					rit = tmprit;
+					if (rit != oldrit){
+						oldrit = rit;
+						TRTR(1, "rig_get_rit(#%d, %s, %ld)", trig->nr, rig_strvfo(vfo), rit);
+						zselect_msg_send(zsel, "TRIG;%d;rit;%ld", trig->nr, rit);
+					}
+				}
+			}
             continue;
         }
 
@@ -699,8 +789,42 @@ gpointer trig_main(gpointer xxx){
 					gtrigs->rigerr = trig->rigerr = rigerr;
 					break;
 				}
-
 				break;
+#ifdef HAVE_RIG_SEND_VOICE_MEM
+			case TRIG_SEND_VOICE_MEM:
+				usleep(trig->poll_ms * 1000);
+				rigerr = rig_send_voice_mem(trig->rig, RIG_VFO_CURR, job->ch);
+				TRTR(1, "rig_send_voice_mem(#%d, RIG_VFO_CURR, %d) ", trig->nr, job->ch);
+				if (rigerr != RIG_OK) {
+					gtrigs->rigerr = trig->rigerr = rigerr;
+					break;
+				}
+				break;
+#endif
+#ifdef HAVE_RIG_SEND_MORSE
+			case TRIG_SEND_MORSE:
+				usleep(trig->poll_ms * 1000);
+				rigerr = rig_send_morse(trig->rig, RIG_VFO_CURR, job->msg);
+				TRTR(1, "rig_send_morse(#%d, RIG_VFO_CURR, '%s') ", trig->nr, job->msg);
+				g_free(job->msg);
+				if (rigerr != RIG_OK) {
+					gtrigs->rigerr = trig->rigerr = rigerr;
+					break;
+				}
+				break;
+#endif
+#ifdef HAVE_RIG_STOP_MORSE
+			case TRIG_STOP_MORSE:
+				usleep(trig->poll_ms * 1000);
+				rigerr = rig_stop_morse(trig->rig, RIG_VFO_CURR);
+				TRTR(1, "rig_stop_morse(#%d, RIG_VFO_CURR) ", trig->nr);
+				g_free(job->msg);
+				if (rigerr != RIG_OK) {
+					gtrigs->rigerr = trig->rigerr = rigerr;
+					break;
+				}
+				break;
+#endif
         }
     }
     return 0;
